==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Munka</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Magánélet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Egy nappal kezdés előtt</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Emlékeztessen holnap</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 perc múlva</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 óra múlva</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 óra múlva</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Holnap</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Ütemezési emlékeztető</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1-től %2-ig</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Egy nappal kezdés előtt</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Bezárás</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Emlékeztessen holnap</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Emlékeztessen később</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Ütemezési emlékeztető</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1-től %2-ig</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Ma</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Holnap</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Munka</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Magánélet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Egy nappal kezdés előtt</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Emlékeztessen holnap</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 perc múlva</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 óra múlva</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 óra múlva</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Holnap</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Ütemezési emlékeztető</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1-től %2-ig</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
